# Configuration that really wants to be per-user,
# but can't be defined from Home Manager.
{
  config,
  lib,
  pkgs,
  ...
}: {
  networking.firewall = lib.mkMerge [
    # User-mode Syncthing
    {
      allowedTCPPorts = [22000];
      allowedUDPPorts = [21027 22000];
    }

    # LocalSend
    {allowedTCPPorts = [53317];}
  ];

  environment.systemPackages = lib.mkMerge [
    [pkgs.ryujinx]
    [
      (pkgs.lutris.override {
        extraLibraries = pkgs: [
          pkgs.libvdpau
          pkgs.openal
          pkgs.speex
          pkgs.libgudev
        ];
      })
      pkgs.wineWowPackages.waylandFull
    ]
    # For gamemode status in GNOME
    (lib.mkIf (config.services.xserver.desktopManager.gnome.enable) [
      pkgs.gnomeExtensions.gamemode-indicator-in-system-settings
    ])
  ];

  programs.steam = {
    enable = true;
    remotePlay.openFirewall = true;
    gamescopeSession.enable = true;
  };
  programs.gamemode = {
    enable = true;
    enableRenice = true;
    settings = {
      general = {
        softrealtime = "auto";
        renice = 10;
      };
    };
  };
}
